summaryrefslogtreecommitdiff
path: root/install.php
diff options
context:
space:
mode:
authorDries Buytaert <dries@buytaert.net>2009-09-14 07:33:55 +0000
committerDries Buytaert <dries@buytaert.net>2009-09-14 07:33:55 +0000
commit0b7962ca0168d65cfb6516792ae2af6c26005c20 (patch)
tree2b9b86e3d77913888f74d4b04b41fcda44480896 /install.php
parente1ad90ba40b74ec103b9113e49b9792b2b422d22 (diff)
downloadbrdo-0b7962ca0168d65cfb6516792ae2af6c26005c20.tar.gz
brdo-0b7962ca0168d65cfb6516792ae2af6c26005c20.tar.bz2
- Patch #570572 by winston, David_Rothstein | Shai, Xano, alexanderpas, emmajane, kazar: changed label for user/1 account from 'administrator' to 'site maintenance account'.
Diffstat (limited to 'install.php')
-rw-r--r--install.php14
1 files changed, 6 insertions, 8 deletions
diff --git a/install.php b/install.php
index a52f9da1c..5322b4677 100644
--- a/install.php
+++ b/install.php
@@ -45,7 +45,7 @@ define('INSTALL_TASK_RUN_IF_REACHED', 2);
* once and be marked complete once they are successfully finished. For
* example, the Drupal installer uses this flag for the batch installation of
* modules on the new site, and also for the configuration form that collects
* basic site information and sets up the first user account.
*/
define('INSTALL_TASK_RUN_IF_NOT_COMPLETED', 3);
@@ -1000,8 +1000,7 @@ function install_find_profiles() {
}
/**
- * Installation task; allow the site administrator to select which profile to
- * install.
+ * Installation task; select which profile to install.
*
* @param $install_state
* An array of information about the current installation state. The chosen
@@ -1117,8 +1116,7 @@ function install_find_locales($profilename) {
}
/**
- * Installation task; allow the site administrator to select which locale to
- * use for the current profile.
+ * Installation task; select which locale to use for the current profile.
*
* @param $install_state
* An array of information about the current installation state. The chosen
@@ -1555,7 +1553,7 @@ function _install_configure_form(&$form_state, &$install_state) {
);
$form['admin_account'] = array(
'#type' => 'fieldset',
- '#title' => st('Administrator account'),
+ '#title' => st('Site maintenance account'),
'#collapsible' => FALSE,
);
@@ -1677,8 +1675,8 @@ function install_configure_form_submit($form, &$form_state) {
if ($form_state['values']['update_status_module'][1]) {
drupal_install_modules(array('update'));
// Add the administrator's email address to the list of addresses to be
// notified when updates are available, if selected.
if ($form_state['values']['update_status_module'][2]) {
variable_set('update_notify_emails', array($form_state['values']['account']['mail']));
}
@@ -45,7 +45,7 @@ define('INSTALL_TASK_RUN_IF_REACHED', 2);
* example, the Drupal installer uses this flag for the batch installation of
* modules on the new site, and also for the configuration form that collects
- * basic site information and sets up the first user account.
+ * basic site information and sets up the site maintenance account.
*/
define('INSTALL_TASK_RUN_IF_NOT_COMPLETED', 3);
@@ -1677,8 +1675,8 @@ function install_configure_form_submit($form, &$form_state) {
if ($form_state['values']['update_status_module'][1]) {
drupal_install_modules(array('update'));
- // Add the administrator's email address to the list of addresses to be
- // notified when updates are available, if selected.
+ // Add the site maintenance account's email address to the list of
+ // addresses to be notified when updates are available, if selected.
if ($form_state['values']['update_status_module'][2]) {
variable_set('update_notify_emails', array($form_state['values']['account']['mail']));